#
# spec file for package lepton
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           lepton
Version:        1.2.1+git.20170405
Release:        4.1
Summary:        Tool and file format for losslessly compressing JPEGs
License:        Apache-2.0
Group:          Productivity/Archiving/Compression
Url:            https://github.com/dropbox/lepton
Source:         %{name}-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  python
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(zlib)
Exclusivearch:  x86_64

%description
Lepton is a tool and file format for losslessly compressing JPEGs by an
average of 22%.

This can be used to archive large photo collections, or to serve images
live and save 22% bandwidth.

%prep
%setup -q

%build
autoreconf -fiv
%configure \
  --enable-system-dependencies
make %{?_smp_mflags}

%install
%make_install

%check
make %{?_smp_mflags} check

%files
%defattr(-,root,root)
%doc README.md LICENSE
%{_bindir}/lepton
%{_bindir}/test_invariants

%changelog
* Thu Apr 13 2017 mpluskal@suse.com
- Update to version 1.2.1+git.20170405:
  * explicitly make padbit signed. Try to fix some  quirks in cmake for powerpc
  * make autotools use sane default compiler flags if none are provided in the command line
  * on ppc when -std=c++11 is defined, the __linux macro goes away
  * added documentation to seeming typo
  * fix #87 : always check that threads_required set up the appropriate number of threads---fire off nop functions on unused threads for consistency
  * check divide by zero, fixing #86
  * only build -scalar in ppc case
* Tue Mar 28 2017 mpluskal@suse.com
- Update to version 1.2.1+git.20170328:
  * Fix #85 32 bit platform support
* Thu Mar 16 2017 mpluskal@suse.com
- Update to version 1.2.1+git.20170311:
  * Cleaned up cmake config. CMake Config was messy, it is less so now Fixed inconsistent case usage Fixed indentation
  * Get lepton building with emscripten + cmake
  * Add a lepton-scalar target
  * Reduce memory usage by disabling custom malloc under emscripten, enabled -O2 optimizations (only work for lepton-scalar)
  * Added a javascript wrapper for the emscripten compiled lepton-scalar
  * added scalar checks to ./configure and to travis.yml
  * added config options to force standard memory allocators and adjust seccomp rules accordingly
  * be explicit about if a dev_assert happens versus a always_assert... demote any assert() that's costly to dev_assert
  * add billing as an option independent of NDEBUG
  * added a PacketReader interface to allow for streaming of data into the vpx_reader
  * change rand to simply use modular arithmetic for the test reader class
  * make the streaming work for single threaded case
  * intrusive list nodes
  * use correct thread_id for setting up the packet readers
  * plumb the thread communication through the whole stack. Ugly init semantics for SendToVirtualThread state)
  * getting close: initialize the bool decoder later, when the streams are available
  * make single thread work again for progressive files
  * added baseline version of the progressive reading of data
  * remove some debug printouts:
  * remove preload of the mux_reader, since that is allocated bit-by-bit
  * receive data queued up in batches from the main thread, if available
  * trying to make a unified model where every thread is treated equally, and thus can finish at a more similar timestamp
  * fix singlethread progressive case
  * make unified framework operate with progressive files...both single threaded and multi
  * give the first worker its own full thread to fully decouple the I/O with the processing so that we don't starve the other workers
  * set the thread mapping before kicking off the first thread
  * setup memmgr with right number of threads
  * added test of an image encoded with more threads than available by default
  * fix multithreaded issue when more virtual threads exist than workers
  * remove the legacy nonunified thread model code, coalesce single-threaded code in the recode.cc case
  * simplified the decode_chunk progressive inner loop
  * startup all threads before waiting for them to start
  * wipe pthread
  * fewer assert statements... simpler reasoning?
  * Include a copy of the Apache license
  * added a test for failing round trip
  * prewarm get_nprocs for ubuntu12.04 compatibility with using posix_memalign under seccomp filters
  * this should make perf significantly worse; but it gets better... unclear why
  * Added a benchmark mode for lepton take filename as arg instead of including it... the reasonable include in smalljpg.hh is sufficient benchmark to produce meaningful stats
  * use std::mutex instead of std::atomic for thread synchronization when STANDARD_MEMORY_ALLOCATORS are on...this helps race detection tools and is simpler to reason about.
  * no longer define __APPLE__ to isolate threads
  * added some extra error handling and fixed a loop for decoding of progressive zero runs
  * add some initialization to constructors to make it easier to reason about. Also set EOBrun to better detect runs
  * remove buffer leak from benchmark
  * allow benchmark to finish early if you want to test less system load
  * windows support
  * between logical threads, never assume previous thread overran its bound
  * prewarm get_nprocs for ubuntu12.04 compatibility with using posix_memalign under seccomp filters
  * Fixed benchmark to work with custom allocators. Also added better help explanations to the help output display
  * minor changes to make unused items only defined when they are used
  * better help message on windows
* Sun Dec 18 2016 mpluskal@suse.com
- Update to version 1.2.1+git.20161213:
  * Ensure proc.terminate() is called after unit test
  * ioutil: poll.h -> sys/select.h
  * close opened file descriptors properly
  * Revert "close opened file descriptors properly"
  * resource leak: fp
  * Fix posix_memalign call
  * Added missing 'defined'.
  * fix uninitialized variable
* Fri Oct 21 2016 mpluskal@suse.com
- Update to version 1.2.1+git.20160921:
  * make sockettester and forktester python3 compatible
  * Ensure proc.terminate() is called after unit test
  * ioutil: poll.h -> sys/select.h
  * close opened file descriptors properly
  * Revert "close opened file descriptors properly"
  * resource leak: fp
  * Fix posix_memalign call
  * Added missing 'defined'.
* Thu Aug 25 2016 mpluskal@suse.com
- Update to version 1.2.1+git.20160813:
  * ioutil: poll.h -> sys/select.h
  * close opened file descriptors properly
* Thu Aug  4 2016 mpluskal@suse.com
- Update to version 1.2.1+git.20160802:
  * Added wrapper libraries section to README
  * formatting
  * rename it to LICENSE.md
  * removing the extension
  * fixes for #47 : i386 compat
  * Add php bindings notice to README.md
  * make sockettester and forktester python3 compatible
  * Ensure proc.terminate() is called after unit test
* Tue Jul 19 2016 mpluskal@suse.com
- Update to version 1.2.1+git.20160718:
  * /build for .gitignore
  * 64-bit-related fixes
  * Win32 build improvements
  * Fixed types to be 32-bit in all cases, fixed comments
  * Unified types
  * remove unused components of zlib
  * it builds now, but will it run; the way things are going I don't know...
* Fri Jul 15 2016 mpluskal@suse.com
- Initial package for version 1.0
